@@ -13,7 +13,7 @@
    For a copy of the GNU General Public License see
    <http://www.gnu.org/licenses/>.
 
-    Copyright 2020 Thomas Dauser, Remeis Observatory & ECAP
+    Copyright 2022 Thomas Dauser, Remeis Observatory & ECAP
 */
 
 #include "reltable.h"
@@ -232,7 +232,7 @@ static relDat *load_single_relDat(fitsfile *fptr, char *extname, int nhdu, int *
 }
 
 /** load the complete relline table */
-void read_relline_table(char *filename, relTable **inp_tab, int *status) {
+void read_relline_table(const char *filename, relTable **inp_tab, int *status) {
 
   relTable *tab = (*inp_tab);
   fitsfile *fptr = NULL;
@@ -367,18 +367,28 @@ lpDat *load_single_lpDat(fitsfile *fptr, int n_h, int n_rad, int rownum, int *st
     CHECK_STATUS_RET(*status, NULL);
   }
 
+  int jj;
+  int kk;
+  for (jj = 0; jj < n_h; jj++) {
+    for (kk = 0; kk < n_rad; kk++) {
+      dat->del_inc[jj][kk] = fabsf(dat->del_inc[jj][kk]);
+      dat->del[jj][kk] = fabsf(dat->del[jj][kk]);
+    }
+  }
+
+
   return dat;
 }
 
 /** load the complete relline table */
-void read_lp_table(char *filename, lpTable **inp_tab, int *status) {
+void read_lp_table(const char *filename, lpTable **inp_tab, int *status) {
 
   lpTable *tab = (*inp_tab);
   fitsfile *fptr = NULL;
 
   char fullfilename[999];
 
-  do { // Errot handling loop
+  do { // Error handling loop
     if (tab != NULL) {
       RELXILL_ERROR("relline LP table already loaded", status);
       break;
@@ -476,6 +486,7 @@ void free_relTable(relTable *tab) {
     free(tab->a);
     free(tab->mu0);
     free(tab);
+    tab = NULL;
   }
 }
 
